﻿using System;
using System.Drawing;
using System.Text;

using DevExpress.XtraEditors;
using DevExpress.XtraRichEdit;
using DevExpress.XtraRichEdit.API.Native;

namespace TestProject
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : XtraForm
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            this.richEditControl.ActiveViewType = RichEditViewType.Simple;

            this.richEditControl.Options.HorizontalScrollbar.Visibility = RichEditScrollbarVisibility.Hidden;
            this.richEditControl.Options.VerticalScrollbar.Visibility   = RichEditScrollbarVisibility.Auto;

            this.richEditControl.Document.DefaultCharacterProperties.FontName  = "나눔고딕코딩";
            this.richEditControl.Document.DefaultCharacterProperties.FontSize  = 12f;
            this.richEditControl.Document.DefaultCharacterProperties.ForeColor = Color.Black;

            this.richEditControl.Document.ParagraphStyles[0].FontName  = "나눔고딕코딩";
            this.richEditControl.Document.ParagraphStyles[0].FontSize  = 12f; 
            this.richEditControl.Document.ParagraphStyles[0].ForeColor = Color.Black;

            this.richEditControl.LoadDocument("sample.rtf");

            this.parseButton.Click += parseButton_Click;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 분석 버튼 클릭시 처리하기 - parseButton_Click(sender, e)

        /// <summary>
        /// 분석 버튼 클릭시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void parseButton_Click(object sender, EventArgs e)
        {
            Document document = this.richEditControl.Document;

            StringBuilder stringBuilder = new StringBuilder();

            foreach(Paragraph paragraph in document.Paragraphs)
            {
                ReadOnlyDocumentImageCollection imageCollection = document.Images.Get(paragraph.Range);

                if(imageCollection == null || imageCollection.Count == 0)
                {
                    stringBuilder.AppendLine($"문단 : {document.GetText(paragraph.Range)}");
                }
                else
                {
                    foreach(DocumentImage documentImage in imageCollection)
                    {
                        stringBuilder.AppendLine($"이미지 : {documentImage.Size}");
                    }
                }
            }

            this.memoEdit.Text = stringBuilder.ToString();
        }

        #endregion
    }
}